from django.conf.urls import patterns, include, url
from django.conf import settings
from django.views.generic import RedirectView
from django.core.urlresolvers import reverse_lazy
from django.contrib.auth.decorators import login_required

from django.contrib import admin

from haystack.views import search_view_factory
from haystack.forms import FacetedSearchForm
from haystack.query import SearchQuerySet

from emissions.views import FacetedSearchView
from emissions.urls import urlpatterns as emissions_urlpatterns
from emissions.models import Emission, Episode, NewsItem
from newsletter.urls import management_patterns as newsletter_urlpatterns
from matos.urls import urlpatterns as matos_urlpatterns
from nonstop.urls import urlpatterns as nonstop_urlpatterns

from combo.manager.urls import urlpatterns as combo_manager_urls

from urls_utils import decorated_includes, cms_permission_required


sqs = SearchQuerySet().models(Emission, Episode, NewsItem).facet('categories').facet('tags')

urlpatterns = patterns('',
    url(r'^$', 'panikdb.views.home', name='home'),
    (r'^ckeditor/', include('ckeditor.urls')),
    url(r'^search/', search_view_factory(view_class=FacetedSearchView,
        form_class=FacetedSearchForm, searchqueryset=sqs), name='haystack_search'),

    url(r'^emissions/$', 'panikdb.views.emissions_list', name='emission-list'),

    url(r'^emissions/',
        decorated_includes(login_required, include(emissions_urlpatterns))),

    url(r'^matos/',
        decorated_includes(login_required, include(matos_urlpatterns))),

    url(r'^nonstop/',
        decorated_includes(login_required, include(nonstop_urlpatterns))),

    url(r'^newsletters/add$', 'panikdb.views.newsletter_create', name='newsletter-create'),
    url(r'^newsletters/',
        decorated_includes(login_required, include(newsletter_urlpatterns))),

    url(r'^cms/',
        decorated_includes(cms_permission_required, include(combo_manager_urls))),

    url(r'^news/$', 'panikdb.views.news', name='news-list'),

    url(r'^focus/set/(?P<object_type>[\w,-]+)/(?P<object_id>\d+)$',
        'panikdb.views.focus_set', name='focus-set'),
    url(r'^focus/unset/(?P<object_type>[\w,-]+)/(?P<object_id>\d+)$',
        'panikdb.views.focus_unset', name='focus-unset'),

    url(r'^cms/pages/(?P<page_pk>\w+)/make-topik$', 'panikdb.views.make_topik',
        name='make-topik'),
    url(r'^cms/pages/topik/(?P<pk>\w+)/edit-topik$', 'panikombo.views.topik_edit',
        name='edit-topik'),

    url(r'^accounts/logout/', 'django.contrib.auth.views.logout_then_login', name='logout'),
    url(r'^accounts/', include('registration.backends.default.urls')),

    url(r'^combok/soundfiles/', 'panikombo.views.soundfiles'),
    url(r'^combok/episodes/', 'panikombo.views.episodes'),

    url(r'^admin/', include(admin.site.urls)),
)

from django.contrib.staticfiles.urls import staticfiles_urlpatterns
urlpatterns += staticfiles_urlpatterns()

from django.conf.urls.static import static
urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
